@@ -23,6 +23,7 @@
 #include "UnityLauncher.h"
 #include "FeaturedModel.h"
 #include "CachedNetworkAccessManager.h"
+#include "DiscoverDeclarativePlugin.h"
 
 // Qt includes
 #include <QAction>
@@ -51,12 +52,14 @@
 #include <KHelpMenu>
 #include <KShortcutsDialog>
 #include <KConcatenateRowsProxyModel>
+#include <KSharedConfig>
+#include <KConfigGroup>
 // #include <KSwitchLanguageDialog>
 
 // DiscoverCommon includes
-#include <MuonDataSources.h>
 #include <resources/AbstractResource.h>
 #include <resources/ResourcesModel.h>
+#include <resources/ResourcesProxyModel.h>
 #include <Category/Category.h>
 #include <Category/CategoryModel.h>
 
@@ -96,6 +99,12 @@ DiscoverMainWindow::DiscoverMainWindow(CompactMode mode)
     qmlRegisterUncreatableType<DiscoverMainWindow>("org.kde.discover.app", 1, 0, "DiscoverMainWindow", QStringLiteral("don't do that"));
     setupActions();
 
+    auto uri = "org.kde.discover";
+    DiscoverDeclarativePlugin* plugin = new DiscoverDeclarativePlugin;
+    plugin->setParent(this);
+    plugin->initializeEngine(m_engine, uri);
+    plugin->registerTypes(uri);
+
     //Here we set up a cache for the screenshots
     delete m_engine->networkAccessManagerFactory();
     m_engine->setNetworkAccessManagerFactory(m_networkAccessManagerFactory.data());
@@ -201,41 +210,10 @@ void DiscoverMainWindow::openLocalPackage(const QUrl& localfile)
     }
 }
 
-void DiscoverMainWindow::openApplication(const QUrl& app)
+void DiscoverMainWindow::openApplication(const QUrl& url)
 {
-    Q_ASSERT(!app.isEmpty());
-    rootObject()->setProperty("defaultStartup", false);
-    auto action = new OneTimeAction(
-        [this, app]() {
-            StoredResultsStream* stream = new StoredResultsStream({ResourcesModel::global()->findResourceByPackageName(app)});
-            connect(stream, &StoredResultsStream::finishedResources, stream, [this, stream, app](const QVector<AbstractResource*> &resources) {
-                if (!resources.isEmpty()) {
-                    if (resources.size() > 1)
-                        qWarning() << "many resources found for" << app;
-                    emit openApplicationInternal(resources.first());
-                } else {
-                    rootObject()->setProperty("defaultStartup", true);
-                    showPassiveNotification(i18n("Couldn't open %1", app.toDisplayString()));
-                }
-            });
-        }
-        , this);
-
-    if (ResourcesModel::global()->backends().isEmpty()) {
-        connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, action, &OneTimeAction::trigger);
-    } else {
-        action->trigger();
-    }
-}
-
-QUrl DiscoverMainWindow::featuredSource() const
-{
-    return MuonDataSources::featuredSource();
-}
-
-QUrl DiscoverMainWindow::prioritaryFeaturedSource() const
-{
-    return QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasmadiscover/featured.json")));
+    Q_ASSERT(!url.isEmpty());
+    Q_EMIT openUrl(url);
 }
 
 void DiscoverMainWindow::integrateObject(QObject* object)
