@@ -29,12 +29,12 @@ class AbstractResource;
 class Category;
 class QWindow;
 class QQmlApplicationEngine;
+class CachedNetworkAccessManagerFactory;
+class ResourcesProxyModel;
 
 class DiscoverMainWindow : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QUrl prioritaryFeaturedSource READ prioritaryFeaturedSource CONSTANT)
-    Q_PROPERTY(QUrl featuredSource READ featuredSource CONSTANT)
     Q_PROPERTY(CompactMode compactMode READ compactMode WRITE setCompactMode NOTIFY compactModeChanged)
     Q_PROPERTY(bool isRoot READ isRoot CONSTANT)
     public:
@@ -47,9 +47,6 @@ class DiscoverMainWindow : public QObject
         QStringList modes() const;
         void setupActions();
 
-        QUrl prioritaryFeaturedSource() const;
-        QUrl featuredSource() const;
-
         CompactMode compactMode() const { return m_mode; }
         void setCompactMode(CompactMode mode);
 
@@ -80,6 +77,7 @@ class DiscoverMainWindow : public QObject
 
     Q_SIGNALS:
         void openApplicationInternal(AbstractResource* app);
+        void openUrl(const QUrl& url);
         void listMimeInternal(const QString& mime);
         void listCategoryInternal(Category* cat);
 
@@ -97,6 +95,7 @@ class DiscoverMainWindow : public QObject
         QQmlApplicationEngine * const m_engine;
 
         CompactMode m_mode;
+        QScopedPointer<CachedNetworkAccessManagerFactory> m_networkAccessManagerFactory;
 };
 
 #endif // MUONINSTALLERDECLARATIVEVIEW_H
