@@ -36,7 +36,8 @@ enum FilterType {
     CategoryFilter,
     PkgSectionFilter,
     PkgWildcardFilter,
-    PkgNameFilter
+    PkgNameFilter,
+    AppstreamIdWildcardFilter
 };
 
 class DISCOVERCOMMON_EXPORT Category : public QObject
@@ -45,11 +46,12 @@ Q_OBJECT
 public:
     Q_PROPERTY(QString name READ name CONSTANT)
     Q_PROPERTY(QString icon READ icon CONSTANT)
-    Q_PROPERTY(bool shouldShowTechnical READ shouldShowTechnical CONSTANT)
     Q_PROPERTY(QObject* parent READ parent CONSTANT)
     Q_PROPERTY(QUrl decoration READ decoration CONSTANT)
     Q_PROPERTY(QVariantList subcategories READ subCategoriesVariant CONSTANT)
     explicit Category(QSet<QString>  pluginNames, QObject* parent = nullptr);
+
+    Category(const QString& name, const QString& iconName, const QVector< QPair< FilterType, QString > >& orFilters, const QSet<QString> &pluginName, const QVector<Category *>& subCategories, const QUrl& decoration, bool isAddons);
     ~Category() override;
 
     QString name() const;
@@ -57,7 +59,6 @@ public:
     QVector<QPair<FilterType, QString> > andFilters() const;
     QVector<QPair<FilterType, QString> > orFilters() const;
     QVector<QPair<FilterType, QString> > notFilters() const;
-    bool shouldShowTechnical() const;
     QVector<Category *> subCategories() const;
     QVariantList subCategoriesVariant() const;
 
@@ -66,10 +67,13 @@ public:
     bool blacklistPlugins(const QSet<QString>& pluginName);
     bool isAddons() const { return m_isAddons; }
     QUrl decoration() const;
+    bool matchesCategoryName(const QString &name) const;
 
     Q_SCRIPTABLE bool contains(Category* cat) const;
     Q_SCRIPTABLE bool contains(const QVariantList &cats) const;
 
+    static bool categoryLessThan(Category *c1, const Category *c2);
+
 private:
     QString m_name;
     QString m_iconString;
@@ -77,7 +81,6 @@ private:
     QVector<QPair<FilterType, QString> > m_andFilters;
     QVector<QPair<FilterType, QString> > m_orFilters;
     QVector<QPair<FilterType, QString> > m_notFilters;
-    bool m_showTechnical;
     QVector<Category *> m_subCategories;
 
     QVector<QPair<FilterType, QString> > parseIncludes(const QDomNode &data);
