@@ -41,8 +41,6 @@ class AppPackageKitResource : public PackageKitResource
         QUrl homepage() override;
         QString comment() override;
         QString license() override;
-        QUrl screenshotUrl() override;
-        QUrl thumbnailUrl() override;
         QStringList allPackageNames() const override;
         QList<PackageState> addonsInformation() override;
         QStringList extends() const override;
