@@ -23,13 +23,17 @@
 
 #include <resources/AbstractResource.h>
 #include <QJsonObject>
+#include <Snapd/Snap>
+#include <QSharedPointer>
+
+class SnapBackend;
 
-class AddonList;
 class SnapResource : public AbstractResource
 {
 Q_OBJECT
 public:
-    explicit SnapResource(QJsonObject data, AbstractResource::State state, AbstractResourcesBackend* parent);
+    explicit SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend* parent);
+    ~SnapResource() override = default;
 
     QString section() override;
     QString origin() const override;
@@ -38,8 +42,6 @@ public:
     QString installedVersion() const override;
     QString license() override;
     int size() override;
-    QUrl screenshotUrl() override;
-    QUrl thumbnailUrl() override;
     QUrl homepage() override;
     QStringList categories() override;
     AbstractResource::State state() override;
@@ -54,11 +56,12 @@ public:
     void fetchScreenshots() override;
     QList<PackageState> addonsInformation() override { return {}; }
 
-    void refreshState();
+    void setState(AbstractResource::State state);
 
 public:
     AbstractResource::State m_state;
-    QJsonObject m_data;
+
+    QSharedPointer<QSnapdSnap> m_snap;
 };
 
 #endif // SNAPRESOURCE_H
