@@ -47,7 +47,9 @@ class DISCOVERCOMMON_EXPORT ResourcesProxyModel : public QAbstractListModel, pub
     Q_PROPERTY(AbstractResource::State stateFilter READ stateFilter WRITE setStateFilter NOTIFY stateFilterChanged)
     Q_PROPERTY(QString mimeTypeFilter READ mimeTypeFilter WRITE setMimeTypeFilter)
     Q_PROPERTY(QString search READ lastSearch WRITE setSearch NOTIFY searchChanged)
+    Q_PROPERTY(QUrl resourcesUrl READ resourcesUrl WRITE setResourcesUrl NOTIFY resourcesUrlChanged)
     Q_PROPERTY(QString extends READ extends WRITE setExtends)
+    Q_PROPERTY(bool allBackends READ allBackends WRITE setAllBackends)
     Q_PROPERTY(QVariantList subcategories READ subcategories NOTIFY subcategoriesChanged)
     Q_PROPERTY(bool isBusy READ isBusy NOTIFY busyChanged)
 public:
@@ -64,6 +66,7 @@ public:
         InstalledRole,
         ApplicationRole,
         OriginRole,
+        DisplayOriginRole,
         CanUpgrade,
         PackageNameRole,
         IsTechnicalRole,
@@ -98,11 +101,20 @@ public:
     QString extends() const;
     void setExtends(const QString &extends);
 
+    QUrl resourcesUrl() const;
+    void setResourcesUrl(const QUrl& resourcesUrl);
+
+    bool allBackends() const;
+    void setAllBackends(bool allBackends);
+
     QVariantList subcategories() const;
 
     QVariant data(const QModelIndex & index, int role) const override;
     int rowCount(const QModelIndex & parent = {}) const override;
 
+    Q_SCRIPTABLE int indexOf(AbstractResource* res);
+    Q_SCRIPTABLE AbstractResource* resourceAt(int row) const;
+
     bool isBusy() const { return m_currentStream != nullptr; }
 
     bool lessThan(AbstractResource* rl, AbstractResource* rr) const;
@@ -123,6 +135,7 @@ private:
     QVector<int> propertiesToRoles(const QVector<QByteArray>& properties) const;
     void addResources(const QVector<AbstractResource*> &res);
     void fetchSubcategories();
+    void removeDuplicates(QVector<AbstractResource *>& newResources);
 
     Roles m_sortRole;
     Qt::SortOrder m_sortOrder;
@@ -145,6 +158,7 @@ Q_SIGNALS:
     void stateFilterChanged();
     void searchChanged(const QString &search);
     void subcategoriesChanged(const QVariantList &subcategories);
+    void resourcesUrlChanged(const QUrl &url);
 };
 
 #endif
