@@ -61,12 +61,13 @@ void StandardBackendUpdater::start()
 {
     m_settingUp = true;
     emit progressingChanged(true);
-    setProgress(-1);
-    Q_EMIT progressingChanged(true);
+    setProgress(0);
 
     foreach(AbstractResource* res, m_toUpgrade) {
         m_pendingResources += res;
-        m_backend->installApplication(res);
+        auto t = m_backend->installApplication(res);
+        t->setVisible(false);
+        TransactionModel::global()->addTransaction(t);
     }
     m_settingUp = false;
 
@@ -112,7 +113,7 @@ void StandardBackendUpdater::transactionRemoved(Transaction* t)
 
 void StandardBackendUpdater::refreshUpdateable()
 {
-    if (m_backend->isFetching()) {
+    if (m_backend->isFetching() || isProgressing()) {
         return;
     }
 
@@ -175,6 +176,8 @@ void StandardBackendUpdater::cleanup()
 {
     m_lastUpdate = QDateTime::currentDateTime();
     m_toUpgrade.clear();
+
+    refreshUpdateable();
     emit progressingChanged(false);
 }
 
